%global sphinx_user sphinx
%global sphinx_group sphinx
%global sphinx_home %{_localstatedir}/lib/sphinx

%if ! 0%{?__isa_bits}
%ifarch x86_64 ia64 ppc64 sparc64 s390x alpha ppc64le aarch64
%global __isa_bits 64
%else
%global __isa_bits 32
%endif
%endif

%bcond_with java


Name:		sphinx
Version:	2.2.11
Release:    1%{?dist}
Summary:	Free open-source SQL full-text search engine
License:	GPLv2+
URL:		http://sphinxsearch.com

Source0:	http://sphinxsearch.com/files/%{name}-%{version}-release.tar.gz
Source1:	searchd.service
Patch0:		%{name}-2.0.3-fix_static.patch
Patch1:		listen_local.patch
Patch2:		sphinx-configure-c99.patch
Patch3:		sphinx-c99.patch

BuildRequires:  make
BuildRequires:  gcc gcc-c++
BuildRequires:	expat-devel
BuildRequires:	mariadb-connector-c-devel openssl-devel
BuildRequires:	libpq-devel
BuildRequires:	systemd

Requires(post):		systemd
Requires(preun):	systemd
Requires(postun):	systemd

Requires(pre):		shadow-utils
       

%description
Sphinx is a full-text search engine, distributed under GPL version 2.
Commercial licensing (e.g. for embedded use) is also available upon request.

Generally, it's a standalone search engine, meant to provide fast,
size-efficient and relevant full-text search functions to other
applications. Sphinx was specially designed to integrate well with SQL
databases and scripting languages.

Currently built-in data source drivers support fetching data either via
direct connection to MySQL, or PostgreSQL, or from a pipe in a custom XML
format. Adding new drivers (e.g. native support other DBMSes) is
designed to be as easy as possible.

Search API native ported to PHP, Python, Perl, Ruby, Java, and also
available as a plug-gable MySQL storage engine. API is very lightweight so
porting it to new language is known to take a few hours.

As for the name, Sphinx is an acronym which is officially decoded as SQL
Phrase Index.
For the Sphinx documentation generator, see python-sphinx instead.


%package -n libsphinxclient
Summary:	Pure C search-d client API library


%description -n libsphinxclient
Pure C search-d client API library
Sphinx search engine, http://sphinxsearch.com/


%package -n libsphinxclient-devel
Summary:	Development libraries and header files for libsphinxclient
Requires:	libsphinxclient = %{version}-%{release}


%description -n libsphinxclient-devel
Pure C search-d client API library
Sphinx search engine, http://sphinxsearch.com/


%if %{with java}
%package java
Summary:		Java API for Sphinx
BuildRequires:	java-devel
Requires:		java-headless
Requires:		jpackage-utils


%description java
This package provides the Java API for Sphinx,
the free, open-source full-text search engine,
designed with indexing database content in mind.
%endif

%package php
Summary:	PHP API for Sphinx
Requires:	php-common >= 5.1.6


%description php
This package provides the PHP API for Sphinx,
the free, open-source full-text search engine,
designed with indexing database content in mind.


%prep
%setup -qn %{name}-%{version}-release
%patch0 -p1 -b .fix_static
%patch1 -p1 -b .default_listen
%patch2 -p1
%patch3 -p1

for f in \
	api/java/mk.cmd \
	api/ruby/test.rb \
	api/ruby/spec/%{name}/%{name}_test.sql \
	api/ruby/spec/%{name}/%{name}_test.sql \
; do
	sed -i 's/\r$//' ${f};
done

iconv -f iso8859-1 -t utf-8 doc/%{name}.txt > doc/%{name}.txt.conv && mv -f doc/%{name}.txt.conv doc/%{name}.txt

%build
%if %{__isa_bits} == 64
%configure --sysconfdir=%{_sysconfdir}/%{name} --with-mysql --with-pgsql --enable-id64
%else
%configure --sysconfdir=%{_sysconfdir}/%{name} --with-mysql --with-pgsql
%endif

make %{?_smp_mflags}

pushd api/libsphinxclient
    %configure
    make #%{?_smp_mflags}
popd


%if %{with java}
make -C api/java 
%endif


%install
make install DESTDIR=%{buildroot} INSTALL="%{__install} -p -c"

install -p -D -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/searchd.service

mkdir -p %{buildroot}%{_localstatedir}/log/%{name}

mkdir -p %{buildroot}%{_localstatedir}/run/%{name}

mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}

cp %{buildroot}%{_sysconfdir}/%{name}/%{name}-min.conf.dist \
    %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf
    
sed -i 's|/var/log/searchd.log|%{_localstatedir}/log/%{name}/searchd.log|g' \
    %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

sed -i 's|/var/log/query.log|%{_localstatedir}/log/%{name}/query.log|g' \
    %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

sed -i 's|/var/log/searchd.pid|%{_localstatedir}/run/%{name}/searchd.pid|g' \
    %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

sed -i 's|/var/data|%{_localstatedir}/lib/sphinx|g' \
    %{buildroot}%{_sysconfdir}/%{name}/%{name}.conf

mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
cat > %{buildroot}%{_sysconfdir}/logrotate.d/%{name} << EOF
%{_localstatedir}/log/%{name}/*.log {
       weekly
       rotate 10
       copytruncate
       delaycompress
       compress
       notifempty
       missingok
}
EOF

mkdir -p %{buildroot}%{_tmpfilesdir}
cat > %{buildroot}%{_tmpfilesdir}/%{name}.conf << EOF
d /run/%{name} 755 %{name} root -
EOF

pushd api/libsphinxclient/
    make install DESTDIR=%{buildroot} INSTALL="%{__install} -p -c"
popd

%if %{with java}
mkdir -p %{buildroot}%{_javadir}
install -m 0644 api/java/%{name}api.jar \
    %{buildroot}%{_javadir}/%{name}.jar
ln -s %{_javadir}/%{name}.jar %{buildroot}%{_javadir}/%{name}api.jar
%endif

install -d -m 0755 %{buildroot}%{_datadir}/php
install -m 0644 api/%{name}api.php %{buildroot}%{_datadir}/php

find %{buildroot} -name '*.la' -exec rm -f {} ';'

find %{buildroot} -name '*.a' -exec rm -f {} ';'


%pre
getent group %{sphinx_group} >/dev/null || groupadd -r %{sphinx_group}
getent passwd %{sphinx_user} >/dev/null || \
useradd -r -g %{sphinx_group} -d %{sphinx_home} -s /bin/bash \
-c "Sphinx Search" %{sphinx_user}
exit 0

%post
%systemd_post searchd.service
/sbin/ldconfig libsphinxclient

%preun
%systemd_preun searchd.service


%postun
%systemd_postun_with_restart searchd.service
/sbin/ldconfig libsphinxclient

%posttrans
chown -R %{sphinx_user}:root %{_localstatedir}/log/%{name}/
chown -R %{sphinx_user}:root %{_localstatedir}/run/%{name}/
chown -R %{sphinx_user}:root %{_localstatedir}/lib/%{name}/

%triggerun -- sphinx < 2.0.3-1
/usr/bin/systemd-sysv-convert --save searchd >/dev/null 2>&1 ||:

/sbin/chkconfig --del searchd >/dev/null 2>&1 || :
/bin/systemctl try-restart searchd.service >/dev/null 2>&1 || :


%files
%doc COPYING doc/sphinx.txt sphinx-min.conf.dist sphinx.conf.dist example.sql
%dir %{_sysconfdir}/sphinx
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%exclude %{_sysconfdir}/%{name}/*.conf.dist
%exclude %{_sysconfdir}/%{name}/example.sql
%{_unitdir}/searchd.service
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_tmpfilesdir}/%{name}.conf
%{_bindir}/*
%dir %attr(0755, %{sphinx_user}, root) %{_localstatedir}/log/%{name}
%dir %attr(0755, %{sphinx_user}, root) %{_localstatedir}/run/%{name}
%dir %attr(0755, %{sphinx_user}, root) %{_localstatedir}/lib/%{name}
%{_mandir}/man1/*

%files -n libsphinxclient
%doc COPYING %{?with_java: api/java} api/ruby api/*.php api/*.py api/libsphinxclient/README
%{_libdir}/libsphinxclient-0*.so

%files -n libsphinxclient-devel
%{_libdir}/libsphinxclient.so
%{_includedir}/*

%if %{with java}
%files java
%doc api/java/README COPYING
%{_javadir}/*
%endif

%files php
%doc COPYING
%{_datadir}/php/*

%changelog
* Tue Aug 06 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - -1
- initial build
